# RNApolis

A Python library containing RNA-related bioinformatics functions and classes.

Use `read_3d_structure` to parse a PDB or an mmCIF file

Use `extract_secondary_structure` to annotate all base pairs, base-phosphate, base-ribose and stacking interactions
